import scrapy

from eintf.common.helper import convert_time, cleanse_html
from eintf.db.db import get_collection


class EtfSpider(scrapy.Spider):
    name = "etf"

    start_urls = [
        "https://etf2l.org",
    ]

    def parse(self, response):
        urls = response.css(".post h1>a[title]::attr(href)")
        for url in urls:
            if get_collection("news").find_one({"url": url.get()}) is not None:
                break
            yield scrapy.Request(url=url.get(), callback=self.get_posts)

    def get_posts(self, response):
        url = response.css("h1 a[href]::attr(href)").get(default='').strip()
        title = response.css("h1 a[href]::text").get(default='').strip()
        date = response.css("h4::text").get(default='').strip().strip()
        author = response.css("a[rel=author]::text").get(default='').strip()
        body = response.css(".etf2l_page").get(default='').strip()
        data = {
            "title": title,
            "date": convert_time(date, "%B %d, %Y"),
            "author": author,
            "url": url,
            "source": self.name,
            "content": cleanse_html(body)
        }
        get_collection("news").insert_one(
            data
        )

    def update(self, process):
        spider = EtfSpider
        process.crawl(spider)




import scrapy

from eintf.common.helper import convert_time, cleanse_html
from eintf.db.db import get_collection


class UgcSpider(scrapy.Spider):
    name = "ugc"

    start_urls = [
        "https://www.ugcleague.com/home_tf2h_ALL.cfm",
        "https://www.ugcleague.com/home_tf26_ALL.cfm",
        "https://www.ugcleague.com/home_tf24_ALL.cfm",
        "https://www.ugcleague.com/home_tf22_ALL.cfm",
        "https://www.ugcleague.com/home_atf2h_ALL.cfm",
        "https://www.ugcleague.com/home_atf26_ALL.cfm",
    ]

    def parse(self, response):
        urls = response.css(".col-md-12 p a::attr(href)")
        for url in urls:
            if get_collection("news").find_one({"url": url.get()}) is not None:
                break
            yield scrapy.Request(url=f"https://www.ugcleague.com/{url.get()}", callback=self.get_posts)

    def get_posts(self, response):
        title = response.css(".item-title h4::text").get(default='').strip()
        date_author = response.css(".white-row h5::text").getall()[1].strip()
        date = convert_time(date_author.split("\nby\n")[0].strip(), "%a, %b %d, %Y")
        author = date_author.split(" by ")[1].strip() if " by " in date_author.strip() else ""
        url = f"{response.url}"
        body = response.css(".white-row").get(default='')
        data = {
            "title": title,
            "date": date,
            "author": author,
            "url": url,
            "source": self.name,
            "content": cleanse_html(body).replace('"src', '" src')
        }
        get_collection("news").insert_one(
            data
        )

    def update(self, process):
        spider = UgcSpider
        process.crawl(spider)




import scrapy
from scrapy.crawler import CrawlerProcess

from eintf.common.helper import convert_time, cleanse_html
from eintf.db.db import get_collection


class RglSpider(scrapy.Spider):
    name = "rgl"

    start_urls = [
        "https://rgl.gg/Public/Articles/ArticlesList.aspx",
    ]

    def parse(self, response):
        urls = response.css("#ContentPlaceHolder1_pnlContent a[href*=Default]::attr(href)")[:15]
        for url in urls:
            if get_collection("news").find_one({"url": url.get()}) is not None:
                break
            yield scrapy.Request(url=f"https://rgl.gg/Public/Articles/{url.get()}", callback=self.get_posts)

    def get_posts(self, response):
        title = response.css("span[id*=lblHeader]::text").get(default='').strip()
        body = response.css(".text-center+div[style]+div").get(default='').strip()
        author = response.css("span[id*=lblWriterName]::text").get(default='').strip()
        date = response.css("span[id*=lblDateLive]::text").get(default='').strip()
        data = {
            "title": title,
            "date": convert_time(date, "%m/%d/%Y"),
            "author": author,
            "url": response.url,
            "source": self.name,
            "content": cleanse_html(body)
        }
        get_collection("news").insert_one(
            data
        )

    def update(self, process):
        spider = RglSpider
        process.crawl(spider)




import os

from pymongo import MongoClient

client = MongoClient(os.environ.get("EINDB"))
db = client['eintf']


def get_db():
    return db


def create_collection(collection_name: str):
    if collection_name not in db.list_collection_names():
        db.create_collection(collection_name)


def drop_collection(collection_name: str):
    return db.drop_collection(collection_name)


def insert_to_collection(collection_name: str, update: dict):
    get_collection(collection_name).insert_one(update)


def get_collection(collection_name: str):
    create_collection(collection_name)
    return db.get_collection(collection_name)



import argparse
import sys

from fastapi import FastAPI
from fastapi.params import Query
from starlette.responses import JSONResponse

import uvicorn

from .db.db import get_collection
from .extractor.git import Tool
from .extractor.huds_megalist import HudsMegalist
from .extractor.map.map_crawler import MapSpider
from .extractor.news.news import News

app = FastAPI()


@app.exception_handler(500)
async def exception_handler(request, exc):
    return JSONResponse(content={"success": False, "error": str(exc)}, status_code=500)


@app.get("/")
def read_root():
    return {}


@app.get("/huds/megalist")
def active_huds():
    return list(get_collection("huds").find({}, {"_id": 0}))


@app.get("/huds/megalist/{hud}")
def active_hud(hud):
    return list(get_collection("huds").find_one({"name": hud}, {"_id": 0}))


@app.get("/tools")
def tools():
    return list(get_collection("tools").find({}, {"_id": 0}))


@app.get("/tools/{tool_}")
def tool(tool_):
    return list(get_collection("tools").find({"name": tool_}, {"_id": 0}))


@app.get("/news")
def news(source: str = Query(None, alias="source"), page: int = Query(1, alias="page")):
    if source is None:
        source = {"$ne": None}
    else:
        source = {"$in": source.split(",")}
    return list(get_collection("news").find(
        {"source": source}, {"_id": 0}
    ).sort("date", -1).limit(10).skip(10 * (page - 1)))


@app.get("/maps")
def maps(
        author=Query(None, alias="author"),
        category=Query(None, alias="category"),
        page: int = Query(1, alias="page")
):
    if author is None:
        author = {"$ne": None}
    if category is None:
        category = {"$ne": None}
    return list(get_collection("maps").find({
        "author": author,
        "category": category,
    }, {"_id": 0}).limit(10).skip(10 * (page - 1)))


def update_data(it):
    if it == "huds":
        return HudsMegalist().update()

    elif it == "tools":
        return Tool().update()

    elif it == "news":
        return News().update()

    elif it == "maps":
        return MapSpider().update()

def run():
    parser_ = argparse.ArgumentParser(description="TF2 api")
    parser_.add_argument(
        "-s",
        metavar="start",
        help="Starts the api server",
        required=False,
        action="store_const",
        const=None,
    )
    parser_.add_argument(
        "-u",
        metavar="update",
        type=str,
        default=None,
        help="updates data in db",
        required=False,
    )
    args = parser_.parse_args()
    if "-s" in sys.argv:
        uvicorn.run("eintf.main:app", host="0.0.0.0", port=8000, reload=True)
    elif "-u" in sys.argv and args.u:
        update_data(args.u)



import traceback

import requests

from eintf.db.db import insert_to_collection

release_dict = {}
util_repos = [
    ("PazerOP", "tf2_bot_detector"),
    ("mastercomfig", "mastercomfig"),
    ("JarateKing", "CleanTF2plus"),
    ("CriticalFlaw", "TF2HUD.Editor"),
    ("Narcha", "DemoMan"),
]


class Tool:
    def latest_release(self, repo):
        name = repo[1]
        owner = repo[0]
        release = requests.get(f"https://api.github.com/repos/{owner}/{name}/releases/latest").json()
        if "message" in release and release["message"] == "Not Found":
            release = requests.get(f"https://api.github.com/repos/{owner}/{name}/commits/master").json()
            return {
                "name": name,
                "release": release["commit"]["message"],
                "published_at": release["commit"]["committer"]["date"],
                "assets": list(f"https://github.com/{owner}/{name}/archive/refs/heads/master.zip"),
                "body": "",
                "owner": release["author"]["login"],
                "source": f"https://github.com/{owner}/{name}",
            }
        return {
            "name": name,
            "release": release["name"],
            "published_at": release["published_at"],
            "assets": list(map(self.minify_asset, release["assets"])),
            "body": release["body"],
            "owner": owner,
            "source": f"https://github.com/{owner}/{name}",
        }

    def minify_asset(self, asset: dict):
        return {
            "url": asset["url"],
            "name": asset["name"],
            "browser_download_url": asset["browser_download_url"],
        }

    def update(self):
        try:
            for r in util_repos:
                insert_to_collection("tools", self.latest_release(r))
            return {"success": True}
        except Exception as e:
            traceback.print_exception(e)
            return {"success": False}



import traceback

from scrapy.crawler import CrawlerProcess

from eintf.extractor.news.etf_crawler import EtfSpider
from eintf.extractor.news.rgl_crawler import RglSpider
from eintf.extractor.news.ugc_crawler import UgcSpider

valid_sources = ["etf", "rgl", "ugc"]


class News:
    def update(self, sources=None):
        process = CrawlerProcess()
        if sources is None:
            sources = valid_sources
        try:
            if "etf" in sources:
                EtfSpider().update(process)

            if "rgl" in sources:
                RglSpider().update(process)

            if "ugc" in sources:
                UgcSpider().update(process)

            process.start()

            return {"success": True}

        except Exception as e:
            traceback.print_exception(e)
            return {"success": False}



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['eintf',
 'eintf.common',
 'eintf.db',
 'eintf.extractor',
 'eintf.extractor.map',
 'eintf.extractor.news']

package_data = \
{'': ['*']}

install_requires = \
['bs4>=0.0.1,<0.0.2',
 'fastapi>=0.89.1,<0.90.0',
 'minify-html>=0.10.8,<0.11.0',
 'pymongo>=4.3.3,<5.0.0',
 'requests>=2.28.1,<3.0.0',
 'scrapy>=2.7.1,<3.0.0',
 'uvicorn>=0.20.0,<0.21.0']

entry_points = \
{'console_scripts': ['eintf = eintf.main:run']}

setup_kwargs = {
    'name': 'eintf',
    'version': '0.0.3',
    'description': '',
    'long_description': 'Extractor for some tf2 websites [WIP]\n\n',
    'author': 'kshib',
    'author_email': 'ksyko@pm.me',
    'maintainer': 'None',
    'maintainer_email': 'None',
    'url': 'None',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.10,<4.0',
}


setup(**setup_kwargs)



import time
from datetime import datetime

import minify_html.minify_html
from bs4 import BeautifulSoup


def user_agent():
    return {"User-Agent": "https://github.com/ksh-b/eintf"}


def convert_time(orig_date, orig_format):
    # IDK why but timestamps are off by a day
    return int(datetime.strptime(orig_date, orig_format).timestamp()) + 86400


def cleanse_html(html):
    soup = BeautifulSoup(html, 'html.parser')
    for tag in soup.find_all():
        if tag.name != "a" and tag.name != "img":
            tag.attrs = {}
    return minify_html.minify(str(soup), minify_js=True, minify_css=True, remove_processing_instructions=True)


def now():
    return int(time.time())



import re

import requests

from eintf.common.helper import user_agent
from eintf.db.db import insert_to_collection, get_collection


class HudsMegalist:
    __active_url = "https://raw.githubusercontent.com/Hypnootize/TF2-HUDs-Megalist/master/Active%20Huds%20List.md"

    def update(self):
        return self.__extract(self.__active_url)

    def __extract(self, url):
        try:
            response = requests.get(url, headers=user_agent())
            rows = response.text.split('\n')
            rows = filter(lambda l: "|" in l and "---" not in l, rows)
            rows = map(lambda l: l.replace('\t', ''), rows)
            rows = map(lambda l: re.sub("\\[(.*?)]", "", l), rows)
            rows = list(rows)
            #
            headers = rows.pop(0)
            headers = re.sub('[^a-zA-Z0-9|\n]', ' ', headers.replace('&', '|').lower()).split('|')
            headers = list(map(lambda t: t.replace(' ', '-'), map(lambda h: h.strip(), headers)))
            #

            for row in rows:
                self.__hud_info(row, headers)
            return {"success": True}
        except Exception as e:
            return {"success": False}

    def __hud_info(self, row, headers) -> (str, dict):
        columns = row.split("|")
        headers = list(map(lambda x: x.replace('hud-', ''), headers))
        headers = list(map(lambda x: x.replace('direct-download', 'download'), headers))
        creator_maintainer = columns[1]
        creator = ''
        maintainer = ''
        if '`' in creator_maintainer:
            creator = re.search('`(.*)`', creator_maintainer).group(1)
        if '*' in creator_maintainer:
            maintainer = re.search('\*(.*)\*', creator_maintainer).group(1)
        columns.remove(creator_maintainer)
        columns.insert(1, creator)
        columns.insert(2, maintainer)

        columns = list(map(lambda c: c.strip("()"), columns))

        repositories = columns[4].split(") (")
        columns[4] = repositories

        hud_discussion = columns[7].split(") (")
        columns[7] = hud_discussion
        hud_json = dict(zip(headers, columns))

        if get_collection("huds").find_one({"name": hud_json['name']}) is None:
            insert_to_collection("huds", hud_json)



import re

import requests
import scrapy
from bs4 import BeautifulSoup
from scrapy.crawler import CrawlerProcess

from eintf.common.helper import cleanse_html
from eintf.db.db import get_collection


class MapSpider(scrapy.Spider):
    name = "maps"

    def start_requests(self):
        url = "https://tf2maps.net/sitemap-1.xml"
        xml_data = requests.get(url).content
        soup = BeautifulSoup(xml_data, "xml")
        urls = [loc.text for loc in soup.find_all('loc')]
        urls = list(filter(lambda link: "/downloads/" in str(link), urls))
        for url in urls:
            id_ = url.split("/")[-2]
            if get_collection("blacklist").find_one({"data": id_}) is not None:
                continue
            if get_collection("maps").find_one({"id": id_}) is not None:
                continue
            yield scrapy.Request(url=url, callback=self.parse_map)

    def parse_map(self, response):
        if response.css('span[itemprop]::text').get(default='') != "Maps":
            get_collection("blacklist").insert_one(
                {"data": response.url.split("/")[-2], "reason": "not-map"}
            )
            return
        map_info = {
            'id': response.url.split("/")[-2],
            'name': response.css('.p-title-value::text').get(default='').strip(),
            'version': response.css('.p-title-value span::text').get(default='').strip(),
            'author': response.css('.resourceSidebarGroup a[class*=username] span::text').get(default='').strip(),
            'tagline': response.css('.p-tagline-value span::text').get(default='').strip(),
            'firstRelease': int(
                response.xpath("(//div[@class='resourceSidebarGroup']//time)[1]/@data-time").get(default='').strip()),
            'lastUpdate': int(
                response.xpath("(//div[@class='resourceSidebarGroup']//time)[2]/@data-time").get(default='').strip()),
            'category': response.css(".resourceSidebarGroup a[href*='/categories/']::text").get(default='').strip(),
            'downloadUrl': response.xpath(
                "//div[contains(@class,'resourceSidebarGroup')]//div[@class='p-title-pageAction']//a[contains(@href,'/downloads/')]/@href").get(default='').strip(),
            'screens': list(map(lambda it: re.findall(r'\(.*?\)', it)[0].strip("(')"),
                                response.xpath("//div[@class='xfa_ec_img']/@style").getall())),
            'description': cleanse_html(response.css('.bbWrapper').get(default='')),
        }
        get_collection("maps").insert_one(
            map_info
        )

    def update(self):
        process = CrawlerProcess()
        spider = MapSpider
        process.crawl(spider)
        process.start()
